@@ -2,9 +2,11 @@ package java.util
 
 import java.lang.*
 import java.util.*
+import kotlin.comparisons.*
 
 public object Collections {
-    public fun max<T>(col: Collection<T>, comp: Comparator<in T>): T = java.util.max(col, comp)
+    @Deprecated("Use collection.maxWith(comparator) instead.", ReplaceWith("col.maxWith(comp)"))
+    public fun <T> max(col: Collection<T>, comp: Comparator<in T>): T = java.util.max(col, comp)
 
     @Deprecated("Use list.sort() instead.", ReplaceWith("list.sort()"))
     public fun <T: Comparable<T>> sort(list: MutableList<T>): Unit = java.util.sort(list, naturalOrder())
@@ -14,7 +16,7 @@ public object Collections {
 
     @Deprecated("Use list.reverse() instead.", ReplaceWith("list.reverse()"))
     public fun <T> reverse(list: MutableList<T>): Unit {
-        val size = list.size()
+        val size = list.size
         for (i in 0..(size / 2) - 1) {
             val i2 = size - i - 1
             val tmp = list[i]
@@ -25,7 +27,7 @@ public object Collections {
 }
 
 @library("collectionsMax")
-private fun max<T>(col: Collection<T>, comp: Comparator<in T>): T = noImpl
+private fun <T> max(col: Collection<T>, comp: Comparator<in T>): T = noImpl
 
 @library("collectionsSort")
 private fun <T> sort(list: MutableList<T>, comparator: Comparator<in T>): Unit = noImpl
