@@ -29,7 +29,7 @@ import kotlin.reflect.jvm.internal.impl.load.java.BuiltinMethodsWithDifferentJvm
 import kotlin.reflect.jvm.internal.impl.load.java.BuiltinMethodsWithDifferentJvmName.sameAsRenamedInJvmBuiltin
 import kotlin.reflect.jvm.internal.impl.load.java.BuiltinMethodsWithSpecialGenericSignature.sameAsBuiltinMethodWithErasedValueParameters
 import kotlin.reflect.jvm.internal.impl.load.java.BuiltinSpecialProperties.getBuiltinSpecialPropertyGetterName
-import kotlin.reflect.jvm.internal.impl.load.java.components.DescriptorResolverUtils
+import kotlin.reflect.jvm.internal.impl.load.java.components.DescriptorResolverUtils.resolveOverridesForNonStaticMembers
 import kotlin.reflect.jvm.internal.impl.load.java.components.TypeUsage
 import kotlin.reflect.jvm.internal.impl.load.java.descriptors.JavaConstructorDescriptor
 import kotlin.reflect.jvm.internal.impl.load.java.descriptors.JavaMethodDescriptor
@@ -44,13 +44,14 @@ import kotlin.reflect.jvm.internal.impl.load.java.structure.JavaArrayType
 import kotlin.reflect.jvm.internal.impl.load.java.structure.JavaClass
 import kotlin.reflect.jvm.internal.impl.load.java.structure.JavaConstructor
 import kotlin.reflect.jvm.internal.impl.load.java.structure.JavaMethod
-import kotlin.reflect.jvm.internal.impl.load.java.typeEnhacement.enhanceSignatures
+import kotlin.reflect.jvm.internal.impl.load.java.typeEnhancement.enhanceSignatures
 import kotlin.reflect.jvm.internal.impl.name.Name
 import kotlin.reflect.jvm.internal.impl.resolve.DescriptorFactory
 import kotlin.reflect.jvm.internal.impl.resolve.DescriptorUtils
 import kotlin.reflect.jvm.internal.impl.resolve.OverridingUtil
 import kotlin.reflect.jvm.internal.impl.resolve.scopes.DescriptorKindFilter
 import kotlin.reflect.jvm.internal.impl.serialization.deserialization.ErrorReporter
+import kotlin.reflect.jvm.internal.impl.storage.NotNullLazyValue
 import kotlin.reflect.jvm.internal.impl.types.KotlinType
 import kotlin.reflect.jvm.internal.impl.types.TypeUtils
 import kotlin.reflect.jvm.internal.impl.types.checker.KotlinTypeChecker
@@ -59,14 +60,14 @@ import kotlin.reflect.jvm.internal.impl.utils.addToStdlib.check
 import kotlin.reflect.jvm.internal.impl.utils.addToStdlib.firstNotNullResult
 import java.util.*
 
-public class LazyJavaClassMemberScope(
+class LazyJavaClassMemberScope(
         c: LazyJavaResolverContext,
         override val ownerDescriptor: ClassDescriptor,
         private val jClass: JavaClass
 ) : LazyJavaScope(c) {
 
     override fun computeMemberIndex(): MemberIndex {
-        return object : ClassMemberIndex(jClass, { !it.isStatic() }) {
+        return object : ClassMemberIndex(jClass, { !it.isStatic }) {
             // For SAM-constructors
             override fun getMethodNames(nameFilter: (Name) -> Boolean): Collection<Name>
                     = super.getMethodNames(nameFilter) + getClassNames(DescriptorKindFilter.CLASSIFIERS, nameFilter)
@@ -75,7 +76,7 @@ public class LazyJavaClassMemberScope(
 
     internal val constructors = c.storageManager.createLazyValue {
         val constructors = jClass.getConstructors()
-        val result = ArrayList<JavaConstructorDescriptor>(constructors.size())
+        val result = ArrayList<JavaConstructorDescriptor>(constructors.size)
         for (constructor in constructors) {
             val descriptor = resolveConstructor(constructor)
             result.add(descriptor)
@@ -83,7 +84,7 @@ public class LazyJavaClassMemberScope(
         }
         
         enhanceSignatures(
-                result ifEmpty { emptyOrSingletonList(createDefaultConstructor()) }
+                result.ifEmpty { emptyOrSingletonList(createDefaultConstructor()) }
         ).toReadOnlyList()
     }
 
@@ -151,8 +152,8 @@ public class LazyJavaClassMemberScope(
     }
 
     private fun CallableDescriptor.doesOverride(superDescriptor: CallableDescriptor): Boolean {
-        return OverridingUtil.DEFAULT.isOverridableByIncludingReturnType(
-                superDescriptor, this
+        return OverridingUtil.DEFAULT.isOverridableByWithoutExternalConditions(
+                superDescriptor, this, /* checkReturnType = */ true
         ).result == OverridingUtil.OverrideCompatibilityInfo.Result.OVERRIDABLE
     }
 
@@ -213,14 +214,18 @@ public class LazyJavaClassMemberScope(
         val functionsFromSupertypes = getFunctionsFromSupertypes(name)
 
         if (!name.sameAsRenamedInJvmBuiltin && !name.sameAsBuiltinMethodWithErasedValueParameters) {
-            addFunctionFromSupertypes(result, name, functionsFromSupertypes.filter { isVisibleAsFunctionInCurrentClass(it) })
+            // Simple fast path in case of name is not suspicious (i.e. name is not one of builtins that have different signature in Java)
+            addFunctionFromSupertypes(
+                    result, name,
+                    functionsFromSupertypes.filter { isVisibleAsFunctionInCurrentClass(it) },
+                    isSpecialBuiltinName = false)
             return
         }
 
         var specialBuiltinsFromSuperTypes = SmartSet.create<SimpleFunctionDescriptor>()
 
         // Merge functions with same signatures
-        val mergedFunctionFromSuperTypes = DescriptorResolverUtils.resolveOverrides(
+        val mergedFunctionFromSuperTypes = resolveOverridesForNonStaticMembers(
                 name, functionsFromSupertypes, emptyList(), ownerDescriptor, ErrorReporter.DO_NOTHING)
 
         // add declarations
@@ -236,16 +241,34 @@ public class LazyJavaClassMemberScope(
         val visibleFunctionsFromSupertypes =
                 functionsFromSupertypes.filter { isVisibleAsFunctionInCurrentClass(it) } + specialBuiltinsFromSuperTypes
 
-        addFunctionFromSupertypes(result, name, visibleFunctionsFromSupertypes)
+        addFunctionFromSupertypes(result, name, visibleFunctionsFromSupertypes, isSpecialBuiltinName = true)
     }
 
     private fun addFunctionFromSupertypes(
             result: MutableCollection<SimpleFunctionDescriptor>,
             name: Name,
-            functionsFromSupertypes: Collection<SimpleFunctionDescriptor>
+            functionsFromSupertypes: Collection<SimpleFunctionDescriptor>,
+            isSpecialBuiltinName: Boolean
     ) {
-        result.addAll(DescriptorResolverUtils.resolveOverrides(
-                name, functionsFromSupertypes, result, ownerDescriptor, c.components.errorReporter))
+
+        val additionalOverrides = resolveOverridesForNonStaticMembers(
+                name, functionsFromSupertypes, result, ownerDescriptor, c.components.errorReporter
+        )
+
+        if (!isSpecialBuiltinName) {
+            result.addAll(additionalOverrides)
+        }
+        else {
+            val allDescriptors = result + additionalOverrides
+            result.addAll(
+                    additionalOverrides.map {
+                        resolvedOverride ->
+                        val overriddenBuiltin = resolvedOverride.getOverriddenSpecialBuiltin()
+                                                ?: return@map resolvedOverride
+
+                        resolvedOverride.createHiddenCopyIfBuiltinAlreadyAccidentallyOverridden(overriddenBuiltin, allDescriptors)
+                    })
+        }
     }
 
     private fun addOverriddenBuiltinMethods(
@@ -258,14 +281,14 @@ public class LazyJavaClassMemberScope(
         for (descriptor in candidatesForOverride) {
             val overriddenBuiltin = descriptor.getOverriddenBuiltinWithDifferentJvmName() ?: continue
 
-            if (alreadyDeclaredFunctions.any { it.doesOverride(overriddenBuiltin) }) continue
-
             val nameInJava = getJvmMethodNameIfSpecial(overriddenBuiltin)!!
             for (method in functions(Name.identifier(nameInJava))) {
                 val renamedCopy = method.createRenamedCopy(name)
 
                 if (isOverridableRenamedDescriptor(overriddenBuiltin, renamedCopy)) {
-                    result.add(renamedCopy)
+                    result.add(
+                            renamedCopy.createHiddenCopyIfBuiltinAlreadyAccidentallyOverridden(overriddenBuiltin, alreadyDeclaredFunctions))
+                    break
                 }
             }
         }
@@ -275,17 +298,29 @@ public class LazyJavaClassMemberScope(
                     BuiltinMethodsWithSpecialGenericSignature.getOverriddenBuiltinFunctionWithErasedValueParametersInJava(descriptor)
                     ?: continue
 
-            if (alreadyDeclaredFunctions.any { it.doesOverride(overriddenBuiltin) }) continue
-
             createOverrideForBuiltinFunctionWithErasedParameterIfNeeded(overriddenBuiltin, functions)?.let {
                 override ->
                 if (isVisibleAsFunctionInCurrentClass(override)) {
-                    result.add(override)
+                    result.add(override.createHiddenCopyIfBuiltinAlreadyAccidentallyOverridden(overriddenBuiltin, alreadyDeclaredFunctions))
                 }
             }
         }
     }
 
+    // In case when Java has declaration with signature reflecting one of special builtin we load override of builtin as hidden function
+    // Unless we do it then signature clash happens.
+    // For example see java.nio.CharBuffer implementing CharSequence and defining irrelevant 'get' method having the same signature as in kotlin.CharSequence
+    // We load java.nio.CharBuffer as having both 'get' functions, but one that is override of kotlin.CharSequence is hidden,
+    // so when someone calls CharBuffer.get it results in invoking java method CharBuffer.get
+    // But we still have the way to call 'charAt' java method by upcasting CharBuffer to kotlin.CharSequence
+    private fun SimpleFunctionDescriptor.createHiddenCopyIfBuiltinAlreadyAccidentallyOverridden(
+            specialBuiltin: CallableDescriptor,
+            alreadyDeclaredFunctions: Collection<SimpleFunctionDescriptor>
+    ) = if (alreadyDeclaredFunctions.none { this != it && it.doesOverride(specialBuiltin) })
+            this
+        else
+            createHiddenCopyToOvercomeSignatureClash()
+
     private fun createOverrideForBuiltinFunctionWithErasedParameterIfNeeded(
             overridden: FunctionDescriptor,
             functions: (Name) -> Collection<SimpleFunctionDescriptor>
@@ -307,7 +342,7 @@ public class LazyJavaClassMemberScope(
       }
 
     override fun computeNonDeclaredProperties(name: Name, result: MutableCollection<PropertyDescriptor>) {
-        if (jClass.isAnnotationType()) {
+        if (jClass.isAnnotationType) {
             computeAnnotationProperties(name, result)
         }
 
@@ -322,7 +357,7 @@ public class LazyJavaClassMemberScope(
             searchMethodsInSupertypesWithoutBuiltinMagic(it)
         }
 
-        result.addAll(DescriptorResolverUtils.resolveOverrides(
+        result.addAll(resolveOverridesForNonStaticMembers(
                 name, propertiesFromSupertypes + propertiesOverridesFromSuperTypes, result, ownerDescriptor, c.components.errorReporter))
     }
 
@@ -420,18 +455,15 @@ public class LazyJavaClassMemberScope(
 
     override fun resolveMethodSignature(
             method: JavaMethod, methodTypeParameters: List<TypeParameterDescriptor>, returnType: KotlinType,
-            valueParameters: LazyJavaScope.ResolvedValueParameters
+            valueParameters: List<ValueParameterDescriptor>
     ): LazyJavaScope.MethodSignatureData {
-        val propagated = c.components.externalSignatureResolver.resolvePropagatedSignature(
-                method, ownerDescriptor, returnType, null, valueParameters.descriptors, methodTypeParameters
+        val propagated = c.components.signaturePropagator.resolvePropagatedSignature(
+                method, ownerDescriptor, returnType, null, valueParameters, methodTypeParameters
         )
-        val effectiveSignature = c.components.externalSignatureResolver.resolveAlternativeMethodSignature(
-                method, !propagated.getSuperMethods().isEmpty(), propagated.getReturnType(),
-                propagated.getReceiverType(), propagated.getValueParameters(), propagated.getTypeParameters(),
-                propagated.hasStableParameterNames()
+        return LazyJavaScope.MethodSignatureData(
+                propagated.returnType, propagated.receiverType, propagated.valueParameters, propagated.typeParameters,
+                propagated.hasStableParameterNames(), propagated.errors
         )
-
-        return LazyJavaScope.MethodSignatureData(effectiveSignature, propagated.getErrors() + effectiveSignature.getErrors())
     }
 
     private fun hasOverriddenBuiltinFunctionWithErasedValueParameters(
@@ -451,7 +483,7 @@ public class LazyJavaClassMemberScope(
     private fun SimpleFunctionDescriptor.doesOverrideBuiltinFunctionWithErasedValueParameters(
             builtinWithErasedParameters: FunctionDescriptor
     ): Boolean {
-        if (this.valueParameters.size() != builtinWithErasedParameters.valueParameters.size()) return false
+        if (this.valueParameters.size != builtinWithErasedParameters.valueParameters.size) return false
         if (!this.typeParameters.isEmpty() || !builtinWithErasedParameters.typeParameters.isEmpty()) return false
         if (this.extensionReceiverParameter != null || builtinWithErasedParameters.extensionReceiverParameter != null) return false
 
@@ -475,24 +507,18 @@ public class LazyJavaClassMemberScope(
                 classDescriptor, c.resolveAnnotations(constructor), /* isPrimary = */ false, c.components.sourceElementFactory.source(constructor)
         )
 
-        val valueParameters = resolveValueParameters(c, constructorDescriptor, constructor.getValueParameters())
-        val effectiveSignature = c.components.externalSignatureResolver.resolveAlternativeMethodSignature(
-                constructor, false, null, null, valueParameters.descriptors, Collections.emptyList(), false)
 
-        constructorDescriptor.initialize(
-                classDescriptor.getTypeConstructor().getParameters(),
-                effectiveSignature.getValueParameters(),
-                constructor.getVisibility()
-        )
-        constructorDescriptor.setHasStableParameterNames(effectiveSignature.hasStableParameterNames())
+        val c = c.child(constructorDescriptor, constructor, typeParametersIndexOffset = classDescriptor.declaredTypeParameters.size)
+        val valueParameters = resolveValueParameters(c, constructorDescriptor, constructor.valueParameters)
+        val constructorTypeParameters =
+                classDescriptor.declaredTypeParameters +
+                constructor.typeParameters.map { p -> c.typeParameterResolver.resolveTypeParameter(p)!! }
+
+        constructorDescriptor.initialize(valueParameters.descriptors, constructor.visibility, constructorTypeParameters)
+        constructorDescriptor.setHasStableParameterNames(false)
         constructorDescriptor.setHasSynthesizedParameterNames(valueParameters.hasSynthesizedNames)
 
-        constructorDescriptor.setReturnType(classDescriptor.getDefaultType())
-
-        val signatureErrors = effectiveSignature.getErrors()
-        if (!signatureErrors.isEmpty()) {
-            c.components.externalSignatureResolver.reportSignatureErrors(constructorDescriptor, signatureErrors)
-        }
+        constructorDescriptor.returnType = classDescriptor.defaultType
 
         c.components.javaResolverCache.recordConstructor(constructor, constructorDescriptor)
 
@@ -500,28 +526,27 @@ public class LazyJavaClassMemberScope(
     }
 
     private fun createDefaultConstructor(): ConstructorDescriptor? {
-        val isAnnotation: Boolean = jClass.isAnnotationType()
-        if (jClass.isInterface() && !isAnnotation)
+        val isAnnotation: Boolean = jClass.isAnnotationType
+        if (jClass.isInterface && !isAnnotation)
             return null
 
         val classDescriptor = ownerDescriptor
         val constructorDescriptor = JavaConstructorDescriptor.createJavaConstructor(
                 classDescriptor, Annotations.EMPTY, /* isPrimary = */ true, c.components.sourceElementFactory.source(jClass)
         )
-        val typeParameters = classDescriptor.getTypeConstructor().getParameters()
         val valueParameters = if (isAnnotation) createAnnotationConstructorParameters(constructorDescriptor)
                               else Collections.emptyList<ValueParameterDescriptor>()
         constructorDescriptor.setHasSynthesizedParameterNames(false)
 
-        constructorDescriptor.initialize(typeParameters, valueParameters, getConstructorVisibility(classDescriptor))
+        constructorDescriptor.initialize(valueParameters, getConstructorVisibility(classDescriptor))
         constructorDescriptor.setHasStableParameterNames(true)
-        constructorDescriptor.setReturnType(classDescriptor.getDefaultType())
+        constructorDescriptor.returnType = classDescriptor.defaultType
         c.components.javaResolverCache.recordConstructor(jClass, constructorDescriptor);
         return constructorDescriptor
     }
 
     private fun getConstructorVisibility(classDescriptor: ClassDescriptor): Visibility {
-        val visibility = classDescriptor.getVisibility()
+        val visibility = classDescriptor.visibility
         if (visibility == JavaVisibilities.PROTECTED_STATIC_VISIBILITY) {
             return JavaVisibilities.PROTECTED_AND_PACKAGE
         }
@@ -529,22 +554,22 @@ public class LazyJavaClassMemberScope(
     }
 
     private fun createAnnotationConstructorParameters(constructor: ConstructorDescriptorImpl): List<ValueParameterDescriptor> {
-        val methods = jClass.getMethods()
-        val result = ArrayList<ValueParameterDescriptor>(methods.size())
+        val methods = jClass.methods
+        val result = ArrayList<ValueParameterDescriptor>(methods.size)
 
         val attr = TypeUsage.MEMBER_SIGNATURE_INVARIANT.toAttributes(allowFlexible = false, isForAnnotationParameter = true)
 
         val (methodsNamedValue, otherMethods) = methods.
-                partition { it.getName() == JvmAnnotationNames.DEFAULT_ANNOTATION_MEMBER_NAME }
+                partition { it.name == JvmAnnotationNames.DEFAULT_ANNOTATION_MEMBER_NAME }
 
-        assert(methodsNamedValue.size() <= 1) { "There can't be more than one method named 'value' in annotation class: $jClass" }
+        assert(methodsNamedValue.size <= 1) { "There can't be more than one method named 'value' in annotation class: $jClass" }
         val methodNamedValue = methodsNamedValue.firstOrNull()
         if (methodNamedValue != null) {
-            val parameterNamedValueJavaType = methodNamedValue.getReturnType()
+            val parameterNamedValueJavaType = methodNamedValue.returnType
             val (parameterType, varargType) =
                     if (parameterNamedValueJavaType is JavaArrayType)
                         Pair(c.typeResolver.transformArrayType(parameterNamedValueJavaType, attr, isVararg = true),
-                             c.typeResolver.transformJavaType(parameterNamedValueJavaType.getComponentType(), attr))
+                             c.typeResolver.transformJavaType(parameterNamedValueJavaType.componentType, attr))
                     else
                         Pair(c.typeResolver.transformJavaType(parameterNamedValueJavaType, attr), null)
 
@@ -553,7 +578,7 @@ public class LazyJavaClassMemberScope(
 
         val startIndex = if (methodNamedValue != null) 1 else 0
         for ((index, method) in otherMethods.withIndex()) {
-            val parameterType = c.typeResolver.transformJavaType(method.getReturnType(), attr)
+            val parameterType = c.typeResolver.transformJavaType(method.returnType, attr)
             result.addAnnotationValueParameter(constructor, index + startIndex, method, parameterType, null)
         }
 
@@ -572,7 +597,7 @@ public class LazyJavaClassMemberScope(
                 null,
                 index,
                 Annotations.EMPTY,
-                method.getName(),
+                method.name,
                 // Parameters of annotation constructors in Java are never nullable
                 TypeUtils.makeNotNullable(returnType),
                 method.hasAnnotationParameterDefaultValue(),
@@ -585,11 +610,11 @@ public class LazyJavaClassMemberScope(
     }
 
     private val nestedClassIndex = c.storageManager.createLazyValue {
-        jClass.getInnerClasses().valuesToMap { c -> c.getName() }
+        jClass.innerClasses.associateBy { c -> c.name }
     }
 
     private val enumEntryIndex = c.storageManager.createLazyValue {
-        jClass.getFields().filter { it.isEnumEntry() }.valuesToMap { f -> f.getName() }
+        jClass.fields.filter { it.isEnumEntry }.associateBy { f -> f.name }
     }
 
     private val nestedClasses = c.storageManager.createMemoizedFunctionWithNullableValues {
@@ -598,10 +623,11 @@ public class LazyJavaClassMemberScope(
         if (jNestedClass == null) {
             val field = enumEntryIndex()[name]
             if (field != null) {
+                val createLazyValue: NotNullLazyValue<Collection<Name>> = c.storageManager.createLazyValue {
+                    memberIndex().getAllFieldNames() + memberIndex().getMethodNames({ true })
+                }
                 EnumEntrySyntheticClassDescriptor.create(c.storageManager, ownerDescriptor, name,
-                                                         c.storageManager.createLazyValue {
-                                                             memberIndex().getAllFieldNames() + memberIndex().getMethodNames({true})
-                                                         }, c.components.sourceElementFactory.source(field))
+                                                         createLazyValue, c.resolveAnnotations(field), c.components.sourceElementFactory.source(field))
             }
             else null
         }
@@ -621,7 +647,7 @@ public class LazyJavaClassMemberScope(
     }
 
     override fun getClassNames(kindFilter: DescriptorKindFilter, nameFilter: (Name) -> Boolean): Collection<Name>
-            = nestedClassIndex().keySet() + enumEntryIndex().keySet()
+            = nestedClassIndex().keys + enumEntryIndex().keys
 
     override fun getPropertyNames(kindFilter: DescriptorKindFilter, nameFilter: (Name) -> Boolean): Collection<Name> {
         if (jClass.isAnnotationType()) return memberIndex().getMethodNames(nameFilter)
@@ -634,8 +660,5 @@ public class LazyJavaClassMemberScope(
         }
     }
 
-    // namespaces should be resolved elsewhere
-    override fun getPackage(name: Name) = null
-
-    override fun toString() = "Lazy java member scope for " + jClass.getFqName()
+    override fun toString() = "Lazy java member scope for " + jClass.fqName
 }
